# Telefly
Create Telegram bots in Python.


### Important
> This package is in a really early version. A lot of functions are not implemented yet and the documentation is... not existend.


## Features
- Simple to use
- Very lightweight

## Usage

```bash
$ pip install telefly
```

```python
from telefly import telefly


tf = telefly(TOKEN)

tf.sendMessage(MESSAGE, chatID)

```
